ChangeBundleId class

Inheritance

Constructors

ChangeBundleId([String? bundleId, String? path])

Properties

androidAppBuildGradlePath ↔ String
getter/setter pair
bundleId ↔ String?
getter/setter pair
command → String
no setteroverride
errorMessage → String
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
iosProjectPbxprojPath ↔ String
getter/setter pair
path ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute() → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readAndSplit(String path) → List<String>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited