PathsConst class

Constructors

PathsConst(String screenName)

Properties

controllerClassName → String
class Name
no setter
controllerFileContent → String
no setter
controllerFileName → String
file Name
no setter
controllerFilePath → String
Paths
no setter
controllerFolderName → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
mainViewClassName → String
no setter
mainViewFileContent → String
Contents
no setter
mainViewFileName → String
no setter
mainViewFilePath → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenFolderName → String
folder name
no setter
screenName → String
final
viewFileContent → String
no setter
viewFileName → String
no setter
viewFilePath → String
no setter
viewFolderName → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited